@@ -5,6 +5,8 @@
 from HTMLParser import HTMLParser
 from .text import innerTrim
 
+import lxml
+
 class OutputFormatter(object):
 
     def __init__(self, config):
@@ -26,14 +28,26 @@ class OutputFormatter(object):
     def get_top_node(self):
         return self.top_node
 
-    def get_formatted_text(self, article):
+    def get_formatted(self, article):
+        """
+        Returns the body text of an article, and also the body article
+        html if specified. Returns in (text, html) form.
+        """
         self.top_node = article.top_node
+        html, text = u'', u''
+
         self.remove_negativescores_nodes()
+
+        if article.config.keep_article_html:
+            html = self.convert_to_html()
+
         self.links_to_text()
         self.add_newline_to_br()
         self.replace_with_text()
         self.remove_fewwords_paragraphs(article)
-        return self.convert_to_text()
+
+        text = self.convert_to_text()
+        return (text, html)
 
     def convert_to_text(self):
         txts = []
@@ -45,6 +59,10 @@ class OutputFormatter(object):
                 txts.extend(txt_lis)
         return '\n\n'.join(txts)
 
+    def convert_to_html(self):
+        cleaned_node = self.parser.clean_article_html(self.get_top_node())
+        return self.parser.node_to_string(cleaned_node)
+
     def add_newline_to_br(self):
         for e in self.parser.getElementsByTag(self.top_node, tag='br'):
             e.text = r'\n'
